function permutation = FisherYates (n)
% La fonction 'FisherYates' génère une permutation aléatoire uniforme de {1, ...,
% n}, appelée 'permutation' par l'algorithme de Fisher-Yates.

% On initialise arbitrairement permutation avec toutes les valeurs de 1 à
% n.
permutation = 1:n;

% On va préparer le tableau 'permutation' en commençant par la fin. 'i'
% représente le nombre d'éléments encore en lice pour être tirés ; il est
% donc /décrémenté/ de 1 à chaque étape, d'où le « n:-1:2 ».
for i = n:-1:2
    % 'indice' est l'indice de l'élément à tirer parmi les i éléments
    % restant en lice, qui occupent les i premières places de la liste.
    indice = ceil(i*rand);
    % On place la case d'indice indice en i-ième position, et on met celle
    % qui était en i-ième position à sa place. 'aux' est une varoable
    % auxiliaire servant à procéder à l'échange.
    aux = permutation(i);
    permutation(i) = permutation(indice);
    permutation(indice) = aux;
end

return
end

