function MC_tournoi_strat (N)
% La fonction 'MC_tournoi' évalue la probabilité de victoire de #16 dans le
% tournoi de tennis, en appliquant la technique de stratification (avec
% échantillonnage uniforme). 'N' est le nombre de simulations demandées.

% 'succes' va maintenant être un 5-vecteur comptant les succès strate par
% strate, et 'Nstrat' comptera combien de fois on est tombé dans chaque
% strate.
Nstrat = zeros(1,5);
succes = zeros(1,5);

for i = 1:N
    % On utilise le programme 'seizegagne_strat' qui renvoie non seulement
    % si #16 a gagné, mais aussi dans quelle strate on était.
    [reponse, strate] = seizegagne_strat;
    % On met à jour 'succes' et 'Nstrat' en conséquence.
    Nstrat(strate) = Nstrat(strate) + 1;
    succes(strate) = succes(strate) + reponse;
end

% Maintenant, on évalue pour chaque strate un estimateur de la probabilité
% de succès conditionnellement à être tombé dans cette strate, noté sous la
% forme du 5-vecteur 'p'.
p = succes ./ Nstrat;
% 'variance' est la variance de la variable de Bernoulli dont on estime
% l'espérance, strate par strate (càd. qu'on a un 5-vecteur dont chacune
% des cases est la variance conditionnellement à être tombé dans la strate
% concernée).
variance = p .* (1-p);
% 'var_est' est la variance /de l'estimateur de la probabilité de succès
% dans une strate donnée/.
var_est = variance ./ Nstrat;

% 'taillestrates' est la taille exacte de chaque strate, calculée
% théoriquement.
taillestrates = [91, 52, 28, 14, 10] / 195;
% L'estimateur global 'P' est obtenu comme la somme des taillestrates(i) *
% p(i).
P = sum (taillestrates .* p);
% La variance de l'estimateur global, notée 'VAR_EST', s'obtient comme la
% variance d'une combinaison linéaire de v.a. indépendantes : la
% multiplication par un scalaire multiplie la variance par le carré de ce
% scalaire, et la somme de quantités indépendantes ajoute leurs variances.
VAR_EST = sum (taillestrates.^2 .* var_est);

% Il n'y a plus qu'à calculer la marge d'erreur associée à VAR_EST et à
% afficher le résultat.
fprintf ...
    ('Estimation de la probabilité de succès de #16 : %.7f ± %.7f\n', ...
    P, 1.96*sqrt(VAR_EST));

return
end