function reponse = seizegagne
% La fonction 'seizegagne' simule le tournoi et nous répond si #16 a gagné.
% Pour gagner du temps, on regarde prioritairement les parties du tableau
% concernant #16, et on arrête la calcul dès que #16 est éliminé. En termes
% de méthode de Monte-Carlo, cela correspondrait à une forme (un peu
% dégénérée) de technique de conditionnement : conditionnellement aux
% calculs qu'on a faits jusqu'à l'élimination éventuelle de #16, la réponse
% n'est plus aléatoire mais déterministe, donc on la renvoie tout de suite
% sans poursuivre la simulation. (*1)

% On initialise la valeur de retour 'reponse' à 'false', et on ne la
% basculera à 'true' que si #16 gagne le tournoi.
reponse = false;
% 'joueursenlice' est le tableau des joueurs encore en lice (qui, comme
% nous allons le voir, évoluera d'une façon un peu spéciale). Comme nous
% l'avons dit, cela ne coûte rien d'imposer de mettre #16 en premier, et
% c'est donc ce que nous faisons.
joueursenlice = [16, FisherYates(15)];

% L'astuce consiste donc à regarder prioritairement les rencontres
% concernant #16. Pour cela, au niveau i (consistant à regarder le match
% éventuel de #16 au tour #i), le tableau 'joueursenlice' contiendra
% d'abord #16, puis /tous/ les joueurs que #16 n'a pas encore vus dans sa
% partie de tableau, soit 16-2^(i-1) joueurs. (Ainsi, au tour #i le tableau
% 'joueursenlice' comporte 17-2^(i-1) joueurs). On détermine alors qui sera
% le nouvel adversaire de #16 en procédant au sous-tournoi entre les
% 2^(i-1) joueurs de la branche du tableau aboutissant à ce nouvel
% adversaire, puis on fait joueur #16 contre ce joueur, puis on recopie à
% la suite du vainqueur du match les 16-2^i joueurs restants.
for i = 1:4
    % 'adversaire' est l'adversaire de #16
    adversaire = soustournoi (joueursenlice (2 : 1+2^(i-1)));
    % 'v' est le vainqueur du match entre #16 et adversaire.
    v = vainqueur (16, adversaire);
    % Si #16 a perdu, on peut arrêter tout de suite la simulation et
    % renvoyer 'false'.
    if v ~= 16
        return
    else
        % Notez la fonction 'cat', avec « 2 » comme premier argument, pour
        % mettre deux listes l'une derrière l'autre. Normalement «
        % cat(2,A,B) » peut être raccourci en « [A,B] », mais ici pour
        % une raison que j'ignore Matlab se perd dans la syntaxe quand on
        % essayer de passer par la forme raccourcie.
        joueursenlice = cat (2, 16, joueursenlice (2+2^(i-1) : end));
    end
end

% Si on arrive au bout de la simulation sans avoir eu de retour prématuré,
% c'est que #16 a gagné ; alors il faut retourner 'true'.
reponse = true;
return
end

% (*1) Si vous ne souhaitez par utiliser cette astuce, le programme devient
% tout simplement « reponse = (soustournoi(FisherYates(16)) == 16); ». Mais
% bien sûr, cette simplicité du code se paye par une exécution plus lente.